use crate::entity::benutzer::{self};
use crate::error::AppError;
use crate::model::benutzer::ErstelleBenutzer;
use axum::Json;
use sea_orm::{prelude::*, ActiveValue, DatabaseConnection, DbErr};
use validator::Validate;

pub struct BenutzerRepository {
    db: DatabaseConnection,
}

impl BenutzerRepository {
    pub fn new(db: DatabaseConnection) -> Self {
        Self { db }
    }

    // Benutzer nach ID suchen
    pub async fn find_by_id(&self, id: uuid::Uuid) -> Result<Option<benutzer::Model>, DbErr> {
        benutzer::Entity::find_by_id(id).one(&self.db).await
    }

    pub async fn create_user(
        &self,
        Json(response): Json<ErstelleBenutzer>,
    ) -> Result<Json<benutzer::Model>, AppError> {
        response.validate()?;

        let ersteller_benutzer = benutzer::ActiveModel {
            id: ActiveValue::Set(uuid::Uuid::new_v4()),
            kennung: ActiveValue::Set(response.kennung),
            vorname: ActiveValue::Set(response.vorname),
            nachname: ActiveValue::Set(response.nachname),
            e_mail: ActiveValue::Set(response.email),
            ..Default::default()
        }
        .insert(&self.db)
        .await?;

        Ok(Json(ersteller_benutzer))
    }

    // // Benutzer erstellen
    // pub async fn create_user(
    //     &self,
    //     kennung: String,
    //     nachname: String,
    //     vorname: String,
    //     email: String,
    // ) -> Result<benutzer::Model, DbErr> {
    //     benutzer::ActiveModel {
    //         id: ActiveValue::Set(uuid::Uuid::new_v4()),
    //         kennung: ActiveValue::Set(kennung),
    //         vorname: ActiveValue::Set(vorname),
    //         nachname: ActiveValue::Set(nachname),
    //         e_mail: ActiveValue::Set(email),
    //         ..Default::default()
    //     }
    //     .insert(&self.db)
    //     .await
    // }

    // // Benutzer aktualisieren
    // pub async fn update_user(
    //     &self,
    //     id: i32,
    //     name: Option<String>,
    //     email: Option<String>,
    // ) -> Result<user::Model, DbErr> {
    //     let user = user::Entity::find_by_id(id)
    //         .one(&self.db)
    //         .await?
    //         .ok_or(DbErr::Custom("User not found.".to_owned()))?;
    //
    //     let mut user: user::ActiveModel = user.into();
    //     if let Some(name) = name {
    //         user.name = ActiveValue::Set(name);
    //     }
    //     if let Some(email) = email {
    //         user.email = ActiveValue::Set(email);
    //     }
    //
    //     user.update(&self.db).await
    // }
    //
    // // Benutzer löschen
    // pub async fn delete_user(&self, id: i32) -> Result<(), DbErr> {
    //     user::Entity::delete_by_id(id).exec(&self.db).await?;
    //     Ok(())
    // }
}
